summaryrefslogtreecommitdiffstats
path: root/ci
diff options
context:
space:
mode:
authorNarinder Gupta <narinder.gupta@canonical.com>2017-08-08 09:31:51 +0000
committerGerrit Code Review <gerrit@opnfv.org>2017-08-08 09:31:51 +0000
commitba4effc7aa09a44d0a19a4a652eb92b6c7b48143 (patch)
treecd0a4217b90111a0981fbff119dddf7e5f961a85 /ci
parent985249b59434bb528ab374fd196a6fcc4b851807 (diff)
parent51b883ef68785306ca4441187921ad823f042fd0 (diff)
Merge "Check that nodes have not failed commissioning or testing"
Diffstat (limited to 'ci')
-rwxr-xr-xci/03-maasdeploy.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/ci/03-maasdeploy.sh b/ci/03-maasdeploy.sh
index 835e3f71..1e93627e 100755
--- a/ci/03-maasdeploy.sh
+++ b/ci/03-maasdeploy.sh
@@ -463,10 +463,10 @@ addnodes(){
do
sleep 60
- # Make sure that no nodes have failed commissioning
- if [ "$(maas $PROFILE nodes read | grep 'Failed commissioning' )" ];
+ # Make sure that no nodes have failed commissioning or testing
+ if [ "$(maas $PROFILE nodes read | grep 'Failed' )" ];
then
- echo "Error: Some nodes have failed commissioning" 1>&2
+ echo "Error: Some nodes have failed commissioning or testing" 1>&2
exit 1
fi